#include <stdio.h>
#include <libmc.h>

int main() 
{
  int port=5051;
  MCAgency_t agency;
  agency = MC_Initialize(port, NULL);

  MC_MainLoop(agency);
  return 0;
}
